@@ -1,9 +1,10 @@
 #include <config.h>
 #include <string.h>
 #include <stdio.h>
-#include <glib.h>
-#include <libgnome/gnome-i18n.h>
 #include <locale.h>
+#include <glib.h>
+#include <glib/gi18n.h>
+#include <gconf/gconf-client.h>
 
 #include "gnome-settings-daemon.h"
 #include "gnome-settings-xsettings.h"
@@ -126,7 +127,13 @@ static TranslationEntry translations [] = {
   { "/desktop/gnome/interface/gtk-im-status-style",	"Gtk/IMStatusStyle",
       GCONF_VALUE_STRING,	translate_string_string },
   { "/desktop/gnome/interface/icon_theme",		"Net/IconThemeName",
-      GCONF_VALUE_STRING,	translate_string_string }
+      GCONF_VALUE_STRING,	translate_string_string },
+  { "/desktop/gnome/interface/file_chooser_backend",	"Gtk/FileChooserBackend",
+      GCONF_VALUE_STRING,	translate_string_string },
+  { "/desktop/gnome/interface/menus_have_icons",	"Gtk/MenuImages",
+      GCONF_VALUE_BOOL,		translate_bool_int },
+  { "/desktop/gnome/interface/menubar_accel",  "Gtk/MenuBarAccel",
+      GCONF_VALUE_STRING,      translate_string_string },
 };
 
 static TranslationEntry*
@@ -247,6 +254,7 @@ xft_callback (GConfEntry *entry)
   client = gconf_client_get_default ();
 
   gnome_settings_update_xft (client);
+  g_object_unref (client);
 
   for (i = 0; managers [i]; i++)  
     xsettings_manager_notify (managers [i]);
@@ -433,6 +441,8 @@ gnome_settings_xsettings_load (GConfClient *client)
       else
         {
           process_value (&translations[i], val);
+	  if (val != NULL)
+                  gconf_value_free (val);
         }
       
       ++i;
